# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

- n/a

## 1.0.1 - 2019-02-20

### Fixed

- Added missing files (changelog, license) to PyPI distribution

## 1.0.0 - 2019-02-07

### Added

- Initial release
